<?php
namespace OrganizationsManagement\Controller;
use OrganizationsManagement\Util\Utilities;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\InstanceProvider;

class Operador extends Simple {

    public function gerarSenha(DTO\Request\DataSet $requisicao, DTO\Response $resposta){
        try {
            $detalhes = $requisicao->getDataSet()->getRows()[0];
            $idOrganizacao = empty($detalhes['NRORG']) ? null : $detalhes['NRORG'];
            $emailOperador = empty($detalhes['DSEMAILOPER']) ? null : $detalhes['DSEMAILOPER'];
            InstanceProvider::getService()->getOperador()->redefineSenha($idOrganizacao, $emailOperador);
            $resposta->addMessage(new DTO\Response\Message("Senha gerada com sucesso e enviada para o e-mail do operador."));
        } catch(\Exception $ex){
            $resposta->setError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findAllOperadores(DTO\Request $request, DTO\Response $response)
    {
        try {
            $operadores = InstanceProvider::getService()->getOperador()->findAllOperadores();
            $response->addDataSet(new DataSource\DataSet('operadores', $operadores));
        } catch (\Exception $ex){
            $response->setError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findOperadoresPorCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
        	$cdCliente = $request->getParameter('cdCliente');
            $operators = InstanceProvider::getService()->getOperador()->findOperadoresPorCliente($cdCliente);
            $response->addDataSet(new DataSource\DataSet('operadoresPorCliente', $operators));
        } catch (\Exception $ex){
            $response->setCriticalError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findRelacionarOperadoresComCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
        	$cdcliente = $request->getParameter('cdcliente');
            $operators = InstanceProvider::getService()->getOperador()->findRelacionarOperadoresComCliente($cdcliente);
            $response->addDataSet(new DataSource\DataSet('relacionarOperadoresComCliente', $operators));
        } catch (\Exception $ex){
            $response->setError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveRelacionarOperadoreComCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
            $operadorService = InstanceProvider::getService()->getOperador();
            $operadores = $request->getParameter('operadores');
            $cdcliente = $request->getParameter('cdcliente');
            $idtpoperclie = $request->getParameter('idtpoperclie');
            $nrpriopercli = $request->getParameter('nrpriopercli');
            $idopermastercp = $request->getParameter('idopermastercp');
            $idopermasterzmart = $request->getParameter('idopermasterzmart');
            $operadorService->saveRelacionarOperadoreComCliente($operadores, $cdcliente, $idtpoperclie, $nrpriopercli, $idopermastercp, $idopermasterzmart);
        } catch (\Exception $ex){
            $response->setCriticalError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function deleteRelacionarOperadoreComCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
            $operadorService = InstanceProvider::getService()->getOperador();
            $opearadores = $request->getParameters();
            $operadorService->deleteRelacionarOperadoreComCliente($opearadores);
        } catch (\Exception $ex) {
            $response->setCriticalError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveOperadorMaster(DTO\Request $request, DTO\Response $response)
    {
        try {
            $operadorService = InstanceProvider::getService()->getOperador();
            $operadores = $request->getParameter('operadores');
            $idopermastercp = $request->getParameter('idopermastercp');
            $idopermasterzmart = $request->getParameter('idopermasterzmart');
            $operadorService->saveOperadorMaster($operadores, $idopermastercp, $idopermasterzmart);
        } catch (\Exception $ex){
            $response->setCriticalError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

} 